#include <ESP32-HUB75-MatrixPanel-I2S-DMA.h>
#include <Adafruit_GFX.h>  // Adafruit GFX库，用于显示文本

#define MATRIX_WIDTH   64
#define MATRIX_HEIGHT  64
#define PANEL_ROWS     2  // 使用两块64x64的显示屏
#define PANEL_COLS     1  // 每块屏幕的列数是1（64x64）

// 引脚定义
#define CLK_PIN   18
#define LAT_PIN   19
#define OE_PIN    23
#define A_PIN     25
#define B_PIN     26
#define C_PIN     27
#define D_PIN     14
#define E_PIN     12
#define F_PIN     13
#define G_PIN     5
#define H_PIN     17

// 配置结构体（HUB75_I2S_CFG）
HUB75_I2S_CFG mxconfig(
  MATRIX_WIDTH,    // 屏幕宽度
  MATRIX_HEIGHT,   // 屏幕高度
  16,              // 16位显示颜色
  {CLK_PIN, LAT_PIN, OE_PIN, A_PIN, B_PIN, C_PIN, D_PIN, E_PIN, F_PIN, G_PIN, H_PIN}, // 引脚配置
  HUB75_I2S_CFG::SHIFTREG, // 使用SHIFTREG作为shift_driver类型
  false,           // 不启用I2S DMA
  HUB75_I2S_CFG::HZ_8M,    // 使用8 MHz时钟速度
  1,               // 行数（默认为1）
  false            // 不使用双缓冲
);

// 创建一个屏幕对象
MatrixPanel_I2S_DMA matrix(mxconfig);

void setup() {
  Serial.begin(115200);
  
  // 初始化屏幕
  matrix.begin();
  matrix.setBrightness(50);  // 设置屏幕亮度（范围从0到255）
  matrix.fillScreen(matrix.color565(0, 0, 0));  // 清空屏幕，设置背景为黑色

  // 设置文本样式
  matrix.setTextColor(matrix.color565(255, 255, 255)); // 白色文本
  matrix.setTextSize(1);  // 设置字体大小（1表示正常大小）

  // 在屏幕上显示“雅马哈”
  matrix.setCursor(0, 0);  // 设置文本起始位置
  matrix.print("Yamaha");  // 你可以将"Yamaha"替换为其他显示的文本
}

void loop() {
  matrix.show();  // 使用show()方法刷新显示内容
}