#include <ESP32-HUB75-MatrixPanel-I2S-DMA.h>
#include <U8g2lib.h>

#define PANEL_RES_X 64 // 屏幕宽度
#define PANEL_RES_Y 64 // 屏幕高度
#define PANEL_CHAIN 2  // 两块屏幕拼接

// 配置 LED 矩阵的引脚
HUB75_I2S_CFG::i2s_pins _pins = {
  25, 26, 27, 14, 12, 13, 23, 19, 5, 17, 18, 4, 15, 16,
};

// 初始化屏幕配置
HUB75_I2S_CFG mxconfig(PANEL_RES_X, PANEL_RES_Y, PANEL_CHAIN, _pins);

// 初始化 DMA 显示对象
MatrixPanel_I2S_DMA *dma_display = new MatrixPanel_I2S_DMA(mxconfig);

// U8G2 配置
U8G2_SSD1306_128X64_NONAME_F_HW_I2C u8g2(U8G2_R0, /* reset=*/U8X8_PIN_NONE, /* clock=*/15, /* data=*/14);

void setup() {
  // 初始化 LED 矩阵屏幕
  dma_display->begin();
  dma_display->clearScreen();
  dma_display->setBrightness(100); // 设置亮度 (0-255)

  // 初始化 U8G2 库
  u8g2.begin();
  u8g2.enableUTF8Print();  // 启用 UTF8 支持
  u8g2.setFont(u8g2_font_wqy12_t_gb2312); // 设置中文字体
}

void loop() {
  // 清空缓冲区
  u8g2.clearBuffer();
  
  // 设置光标位置并显示中文字符
  u8g2.setCursor(0, 15); // 设置光标位置
  u8g2.print("济❤️南"); // 显示中文字符
  
  // 刷新显示
  u8g2.sendBuffer();

  delay(1000); // 延时
}